==> beans-ddi-lifecycle-1.0.0-20130314.191755-5-sources.jar: org/openmetadata/beans/ddi/lifecycle/studyunit/StudyUnitBean.java <==
package org.openmetadata.beans.ddi.lifecycle.studyunit;

import org.openmetadata.beans.ddi.lifecycle.adt.DdiBeanList;
import org.openmetadata.beans.ddi.lifecycle.adt.ReferenceSet;
import org.openmetadata.beans.ddi.lifecycle.adt.impl.ReferenceSetImpl;
import org.openmetadata.beans.ddi.lifecycle.archive.ArchiveBean;
import org.openmetadata.beans.ddi.lifecycle.conceptualcomponent.ConceptualComponentBean;
import org.openmetadata.beans.ddi.lifecycle.conceptualcomponent.UniverseBean;
import org.openmetadata.beans.ddi.lifecycle.datacollection.DataCollectionBean;
import org.openmetadata.beans.ddi.lifecycle.logicalproduct.LogicalProductBean;
import org.openmetadata.beans.ddi.lifecycle.physicaldataproduct.PhysicalDataProductBean;
import org.openmetadata.beans.ddi.lifecycle.physicalinstance.PhysicalInstanceBean;
import org.openmetadata.beans.ddi.lifecycle.reusable.CitationBean;
import org.openmetadata.beans.ddi.lifecycle.reusable.IdentifiedStructuredStringValueBean;
import org.openmetadata.beans.ddi.lifecycle.reusable.MaintainableBean;
import org.openmetadata.beans.ddi.lifecycle.reusable.OtherMaterialBean;
import org.openmetadata.beans.ddi.lifecycle.reusable.SeriesStatementBean;
import org.openmetadata.ddi_3_1.util.DdiClass;

public interface StudyUnitBean extends MaintainableBean {
	
	public final static DdiClass ddiClass = DdiClass.StudyUnit;

	public CitationBean getCitation();

	public IdentifiedStructuredStringValueBean getAbstract();

	public IdentifiedStructuredStringValueBean getPurpose();

	public ReferenceSet<ConceptualComponentBean> getConceptualComponentList();

	public ReferenceSet<LogicalProductBean> getLogicalProductList();

	public ReferenceSet<DataCollectionBean> getDataCollectionList();

	public ReferenceSet<ArchiveBean> getArchiveList();

	public ReferenceSet<PhysicalInstanceBean> getPhysicalInstanceList();

	public ReferenceSet<PhysicalDataProductBean> getPhysicalDataProductList();

	public DdiBeanList<OtherMaterialBean> getOtherMaterialList();
	
	public ReferenceSetImpl<UniverseBean> getUniverses();
	
	public SeriesStatementBean getSeriesStatement();

}

==> beans-ddi-lifecycle-1.0.0-20131230.155656-19-sources.jar: org/openmetadata/beans/ddi/lifecycle/studyunit/StudyUnitBean.java <==
package org.openmetadata.beans.ddi.lifecycle.studyunit;

import org.openmetadata.beans.ddi.lifecycle.adt.DdiBeanList;
import org.openmetadata.beans.ddi.lifecycle.adt.ReferenceSet;
import org.openmetadata.beans.ddi.lifecycle.adt.impl.ReferenceSetImpl;
import org.openmetadata.beans.ddi.lifecycle.archive.ArchiveBean;
import org.openmetadata.beans.ddi.lifecycle.conceptualcomponent.ConceptualComponentBean;
import org.openmetadata.beans.ddi.lifecycle.conceptualcomponent.UniverseBean;
import org.openmetadata.beans.ddi.lifecycle.datacollection.DataCollectionBean;
import org.openmetadata.beans.ddi.lifecycle.logicalproduct.LogicalProductBean;
import org.openmetadata.beans.ddi.lifecycle.physicaldataproduct.PhysicalDataProductBean;
import org.openmetadata.beans.ddi.lifecycle.physicalinstance.PhysicalInstanceBean;
import org.openmetadata.beans.ddi.lifecycle.reusable.CitationBean;
import org.openmetadata.beans.ddi.lifecycle.reusable.IdentifiedStructuredStringValueBean;
import org.openmetadata.beans.ddi.lifecycle.reusable.MaintainableBean;
import org.openmetadata.beans.ddi.lifecycle.reusable.OtherMaterialBean;
import org.openmetadata.beans.ddi.lifecycle.reusable.SeriesStatementBean;
import org.openmetadata.ddi_3_1.util.DdiClass;

public interface StudyUnitBean extends MaintainableBean {
	
	final static DdiClass ddiClass = DdiClass.StudyUnit;

	CitationBean getCitation();

	IdentifiedStructuredStringValueBean getAbstract();

	IdentifiedStructuredStringValueBean getPurpose();

	ReferenceSet<ConceptualComponentBean> getConceptualComponentList();

	ReferenceSet<LogicalProductBean> getLogicalProductList();

	ReferenceSet<DataCollectionBean> getDataCollectionList();

	ReferenceSet<ArchiveBean> getArchiveList();

	ReferenceSet<PhysicalInstanceBean> getPhysicalInstanceList();

	ReferenceSet<PhysicalDataProductBean> getPhysicalDataProductList();

	DdiBeanList<OtherMaterialBean> getOtherMaterialList();
	
	ReferenceSetImpl<UniverseBean> getUniverses();
	
	SeriesStatementBean getSeriesStatement();
	
	void setNature(String nature);
	
	boolean isSetNature();
	
	String getNature();
}
